==> mastercard_spendcontrols-1.0.0-py2-none-any.whl: mastercardspendcontrols/declineall.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Declineall(BaseObject):
	"""
	
	"""

	__config = {
		
		"58efbfdb-dd31-4480-9e00-46286327ba4e" : OperationConfig("/issuer/v1/card/{uuid}/controls/declines/all", "delete", [], []),
		
		"d00642e1-eac1-44c5-b371-b8cea993ed4b" : OperationConfig("/issuer/v1/card/{uuid}/controls/declines/all", "query", [], []),
		
		"25bd01e3-3f0c-4ae8-8721-7a9af48b0709" : OperationConfig("/issuer/v1/card/{uuid}/controls/declines/all", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUI)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Declineall by id

		@param str id
		@return Declineall of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("58efbfdb-dd31-4480-9e00-46286327ba4e", Declineall(mapObj))

	def delete(self):
		"""
		Delete object of type Declineall

		@return Declineall of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("58efbfdb-dd31-4480-9e00-46286327ba4e", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Declineall by id and optional criteria
		@param type criteria
		@return Declineall object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("d00642e1-eac1-44c5-b371-b8cea993ed4b", Declineall(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Declineall

		@param Dict mapObj, containing the required parameters to create a new object
		@return Declineall of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("25bd01e3-3f0c-4ae8-8721-7a9af48b0709", Declineall(mapObj))

==> mastercard_spendcontrols-1.0.3-py2-none-any.whl: mastercardspendcontrols/declineall.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class Declineall(BaseObject):
	"""
	
	"""

	__config = {
		
		"cf02aff3-5d48-4b0c-8a2c-28b5261b0020" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/all", "delete", [], []),
		
		"45be4f7f-443e-4a29-896c-cd1fee0496c2" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/all", "query", [], []),
		
		"adbb3224-0bb4-420d-be3e-7a96719714c9" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/all", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUID)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type Declineall by id

		@param str id
		@return Declineall of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("cf02aff3-5d48-4b0c-8a2c-28b5261b0020", Declineall(mapObj))

	def delete(self):
		"""
		Delete object of type Declineall

		@return Declineall of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("cf02aff3-5d48-4b0c-8a2c-28b5261b0020", self)








	@classmethod
	def query(cls,criteria):
		"""
		Query objects of type Declineall by id and optional criteria
		@param type criteria
		@return Declineall object representing the response.
		@raise ApiException: raised an exception from the response status
		"""

		return BaseObject.execute("45be4f7f-443e-4a29-896c-cd1fee0496c2", Declineall(criteria))

	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type Declineall

		@param Dict mapObj, containing the required parameters to create a new object
		@return Declineall of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("adbb3224-0bb4-420d-be3e-7a96719714c9", Declineall(mapObj))
